@@ -10,17 +10,17 @@ class Sender(str, Enum):
 class EventType(str, Enum):
     TRANSCRIPT = "event_transcript"
     PHONE_CALL_CONNECTED = "event_phone_call_connected"
+    PHONE_CALL_ENDED = "event_phone_call_ended"
 
 
 class Event(TypedModel):
-    pass
+    conversation_id: str
 
 
 class TranscriptEvent(Event, type=EventType.TRANSCRIPT):
     text: str
     sender: Sender
     timestamp: float
-    conversation_id: str
 
     def to_string(self, include_timestamp: bool = False) -> str:
         if include_timestamp:
@@ -30,3 +30,7 @@ class TranscriptEvent(Event, type=EventType.TRANSCRIPT):
 
 class PhoneCallConnectedEvent(Event, type=EventType.PHONE_CALL_CONNECTED):
     pass
+
+
+class PhoneCallEndedEvent(Event, type=EventType.PHONE_CALL_ENDED):
+    pass
